pub struct AliasContext(/* private fields */);Expand description
A registry of value-to-alias mappings.
Cheap to clone — all clones share the same underlying registry via
Arc<Mutex<_>>.
Implementations
Sourceimpl AliasContext
impl AliasContext
Sourcepub fn set_brackets(&self, brackets: (&'static str, &'static str))
pub fn set_brackets(&self, brackets: (&'static str, &'static str))
Change the brackets used to wrap aliases in formatted output.
Brackets are snapshotted into each alias at registration time, so this only affects aliases registered after the call.